@@ -10,4 +10,7 @@ def get_icon(mime):
         return 'icon-file'
     elif mime.startswith('video'):
         return 'icon-film'
-    
+    elif mime.startswith('audio'):
+        return 'icon-music'
+    else:
+        return 'icon-file'
